<?php

namespace Drupal\entity_export_csv\Plugin\FieldTypeExport;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\entity_export_csv\Plugin\FieldTypeExportBase;
use Drupal\Core\Field\FieldItemInterface;

/**
 * Defines an Address field type export plugin.
 *
 * @FieldTypeExport(
 *   id = "address_export",
 *   label = @Translation("Address export"),
 *   description = @Translation("Address export"),
 *   weight = 0,
 *   field_type = {
 *     "address",
 *   },
 *   entity_type = {},
 *   bundle = {},
 *   field_name = {},
 *   exclusive = FALSE,
 * )
 */
class AddressExport extends FieldTypeExportBase {

  /**
   * {@inheritdoc}
   */
  public function getSummary() {
    return [
      'message' => [
        '#markup' => $this->t('Address field type exporter.'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state, FieldDefinitionInterface $field_definition) {
    $configuration = $this->getConfiguration();
    $build = parent::buildConfigurationForm($form, $form_state, $field_definition);
    $build['property']['#type'] = 'checkboxes';
    $build['property']['#default_value'] = !empty($configuration['property']) ? $configuration['property'] : [$this->getMainPropertyName($field_definition)];
    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function massageExportPropertyValue(FieldItemInterface $field_item, $property_name, FieldDefinitionInterface $field_definition, $options = []) {
    if ($field_item->isEmpty()) {
      return NULL;
    }
    $configuration = $this->getConfiguration();
    $format = $configuration['format'];
    if (empty($format)) {
      $format = ' ';
    }
    elseif ($format === 'eol') {
      $format = PHP_EOL;
    }

    $values = [];
    if (is_array($property_name)) {
      $property_name = array_filter($property_name);
      foreach ($property_name as $property) {
        $value = $field_item->get($property)->getValue();
        if (is_array($value)) {
          continue;
        }
        $values[] = (string) $value;
      }
      $values = array_filter($values);
      $values = array_reverse($values);
      return implode($format, $values);
    }
    else {
      return $field_item->get($property_name)->getValue();
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function getFormatExportOptions(FieldDefinitionInterface $field_definition) {
    $options = parent::getFormatExportOptions($field_definition);
    $options[''] = $this->t('Default separator ( )');
    $options[' - '] = $this->t('Separator ( - )');
    $options['|'] = $this->t('Separator (|)');
    $options['eol'] = $this->t('Separator (EOL)');
    return $options;
  }

}
