<?php

namespace Drupal\entity_export_csv\Plugin\FieldTypeExport;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\entity_export_csv\Plugin\FieldTypeExportBase;
use Drupal\Core\Field\FieldItemInterface;

/**
 * Defines a Link field type export plugin.
 *
 * @FieldTypeExport(
 *   id = "link_export",
 *   label = @Translation("Link export"),
 *   description = @Translation("Link export"),
 *   weight = 0,
 *   field_type = {
 *     "link",
 *   },
 *   entity_type = {},
 *   bundle = {},
 *   field_name = {},
 *   exclusive = FALSE,
 * )
 */
class LinkExport extends FieldTypeExportBase {

  /**
   * {@inheritdoc}
   */
  public function getSummary() {
    return [
      'message' => [
        '#markup' => $this->t('Link field type exporter.'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function massageExportPropertyValue(FieldItemInterface $field_item, $property_name, FieldDefinitionInterface $field_definition, $options = []) {
    if ($field_item->isEmpty()) {
      return NULL;
    }
    $configuration = $this->getConfiguration();
    if (empty($configuration['format'])) {
      return $field_item->get($property_name)->getValue();
    }

    $format = $configuration['format'];
    if ($format === 'all') {
      $properties = $this->getPropertyExportOptions($field_definition);
      $values = [];
      foreach ($properties as $property => $label) {
        $value = $field_item->get($property)->getValue();
        if (is_array($value)) {
          // @TODO Find a way to implode to string array value for map property.
          continue;
        }
        $values[] = $value;
      }
     return implode('|', $values);
    }

    return $field_item->get($property_name)->getValue();
  }

  /**
   * {@inheritdoc}
   */
  protected function getFormatExportOptions(FieldDefinitionInterface $field_definition) {
    $options = parent::getFormatExportOptions($field_definition);
    $options['all'] = $this->t('All values (|)');
    return $options;
  }

}
